@@ -1,7 +1,7 @@
 /*
  *  Entangle: Tethered Camera Control & Capture
  *
- *  Copyright (C) 2009-2012 Daniel P. Berrange
+ *  Copyright (C) 2009-2015 Daniel P. Berrange
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 
 #include "entangle-camera.h"
 #include "entangle-application.h"
+#include "entangle-script.h"
 
 G_BEGIN_DECLS
 
@@ -59,6 +60,11 @@ struct _EntangleCameraManagerClass
 GType entangle_camera_manager_get_type(void) G_GNUC_CONST;
 EntangleCameraManager* entangle_camera_manager_new(void);
 
+void entangle_camera_manager_add_script(EntangleCameraManager *manager,
+                                        EntangleScript *script);
+void entangle_camera_manager_remove_script(EntangleCameraManager *manager,
+                                           EntangleScript *script);
+
 void entangle_camera_manager_capture(EntangleCameraManager *manager);
 void entangle_camera_manager_preview_begin(EntangleCameraManager *manager);
 void entangle_camera_manager_preview_cancel(EntangleCameraManager *manager);
