@@ -1,7 +1,7 @@
 /*
- *  Entangle: Entangle Assists Photograph Aquisition
+ *  Entangle: Tethered Camera Control & Capture
  *
- *  Copyright (C) 2009 Daniel P. Berrange
+ *  Copyright (C) 2009-2015 Daniel P. Berrange
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -299,7 +299,7 @@ static void entangle_image_histogram_get_preferred_height(GtkWidget *widget,
 {
     g_return_if_fail(ENTANGLE_IS_IMAGE_HISTOGRAM(widget));
 
-    *minheight = 50;
+    *minheight = 170;
     *natheight = 170;
 }
 
@@ -344,8 +344,6 @@ static void entangle_image_histogram_init(EntangleImageHistogram *histogram)
 
     priv = histogram->priv = ENTANGLE_IMAGE_HISTOGRAM_GET_PRIVATE(histogram);
     memset(priv, 0, sizeof *priv);
-
-    gtk_widget_set_double_buffered(GTK_WIDGET(histogram), FALSE);
 }
 
 
